@@ -27,11 +27,16 @@ NAS_PATH = "/Volumes/Multimedia/댄스"
 MLP_PATH_DATA = "/Volumes/FrameData/mlp/data"
 MLP_PATH = "/Volumes/FrameData/mlp"
 LSTM_PATH = "/Volumes/FrameData/lstm"
-LINUX_LSTM_PATH = "/home/jinwoo/jinwoo/lstmData"
+TRANSFORMER_PATH = "/Volumes/FrameData/transformer"
+LINUX_LSTM_PATH = "/home/jinwoo/jinwoo/lstm"
 
-POSE_MEASURE_SAVE_PATH = DIR_PATH + "/utils/poseMeasure.py"
+TAEKWONDO_PATH = "/Volumes/FrameData/TaeKwondo"
+TAEKWONDO_LINUX_PATH = "/home/jinwoo/jinwoo/frameData/TaeKwondo"
+
+POSE_MEASURE_SAVE_PATH = DIR_PATH + "/poseutil/utils/poseMeasure.py"
 
 NO_COUNTING_PATH = "/Volumes/FrameData/no_counting_data"
+APP_LIST = ["pose-test-app", "gymmate-app"]
 
 MAPPING_MAP = {
     "Weight/DumbbellBenchPress": ["Weight/BarbellBenchPress"],
@@ -52,7 +57,7 @@ MAPPING_MAP = {
 }
 #------------------------------------------------------------------------
 # list view Setup
-EMBEDDINGLIST = ["UPPER", "BODYNOSE", "LOWER","FULL", "HAND"]
+EMBEDDINGLIST = ["UPPER", "BODYNOSE", "LOWER","FULL", "HAND", "LOWERYANG", "TAEKWONDO"]
 SIDECHECKLIST = ["SIDE", "FRONT"]
 CONTENTLIST = ["Weight", "Golf", "Yang", "Beginner", "Test"]
 ANGLELIST = [
@@ -219,6 +224,42 @@ ALL_BODY_STR_LIST = [
     "LEFT_HEEL", "RIGHT_HEEL", "LEFT_FOOT_INDEX", "RIGHT_FOOT_INDEX"
 ]
 
+ALLBODY_CONST_DICTIONARY = {
+    "NOSE": NOSE, 
+    "LEFT_EYE_INNER": LEFT_EYE_INNER,
+    "LEFT_EYE": LEFT_EYE,
+    "LEFT_EYE_OUTER": LEFT_EYE_OUTER,
+    "RIGHT_EYE_INNER": RIGHT_EYE_INNER,
+    "RIGHT_EYE": RIGHT_EYE,
+    "RIGHT_EYE_OUTER": RIGHT_EYE_OUTER,
+    "LEFT_EAR": LEFT_EAR,
+    "RIGHT_EAR": RIGHT_EAR,
+    "LEFT_MOUTH": LEFT_MOUTH,
+    "RIGHT_MOUTH" : RIGHT_MOUTH ,
+    "LEFT_SHOULDER" : LEFT_SHOULDER ,
+    "RIGHT_SHOULDER" : RIGHT_SHOULDER ,
+    "LEFT_ELBOW" : LEFT_ELBOW ,
+    "RIGHT_ELBOW" : RIGHT_ELBOW ,
+    "LEFT_WRIST" : LEFT_WRIST ,
+    "RIGHT_WRIST" : RIGHT_WRIST ,
+    "LEFT_PINKY" : LEFT_PINKY ,
+    "RIGHT_PINKY" : RIGHT_PINKY ,
+    "LEFT_INDEX" : LEFT_INDEX ,
+    "RIGHT_INDEX" : RIGHT_INDEX ,
+    "LEFT_THUMB" : LEFT_THUMB ,
+    "RIGHT_THUMB" : RIGHT_THUMB ,
+    "LEFT_HIP" : LEFT_HIP ,
+    "RIGHT_HIP" : RIGHT_HIP ,
+    "LEFT_KNEE" : LEFT_KNEE ,
+    "RIGHT_KNEE" : RIGHT_KNEE ,
+    "LEFT_ANKLE" : LEFT_ANKLE ,
+    "RIGHT_ANKLE" : RIGHT_ANKLE ,
+    "LEFT_HEEL" : LEFT_HEEL ,
+    "RIGHT_HEEL" : RIGHT_HEEL ,
+    "LEFT_FOOT_INDEX" : LEFT_FOOT_INDEX ,
+    "RIGHT_FOOT_INDEX" : RIGHT_FOOT_INDEX
+}
+
 #------------------------------------------------------------------------
 # Color Const RGB
 RED = (200, 50, 50)
@@ -310,8 +351,20 @@ HANDRIGHT = "HANDRIGHT"
 BODYNOSE = "BODYNOSE"
 BODYNOSELEFT = "BDOYNOSELEFT"
 BODYNOSERIGHT = "BODYNOSERIGHT"
+LOWERYANG = "LOWERYANG"
+LOWERYANGLEFT = "LOWERYANGLEFT"
+LOWERYANGRIGHT = "LOWERYANGRIGHT"
 
 
+TAEKWONDO_EMBEDDING = [
+    LEFT_SHOULDER, RIGHT_SHOULDER,
+    LEFT_HIP, RIGHT_HIP,
+    LEFT_KNEE, RIGHT_KNEE,
+    LEFT_ANKLE, RIGHT_ANKLE,
+    LEFT_FOOT_INDEX, RIGHT_FOOT_INDEX,
+    LEFT_HEEL, RIGHT_HEEL
+]
+
 SYNC_TARGET_LOWER = [
     [LEFT_SHOULDER, RIGHT_SHOULDER],
     [LEFT_SHOULDER, LEFT_HIP],
@@ -485,4 +538,42 @@ STANDARD_JOINT_MAP = {
     LEFT_ANKLE: "LEFT_ANKLE"
 }
 
-CONTENTS = ["Weight", "Yang", "Beginner"]
\ No newline at end of file
+CONTENTS = ["Weight", "Yang", "Beginner"]
+
+APP_LIST = ['test', 'gymmate']
+
+TAEKWONDO_LSTM_MAP = {
+    "STANDBY" : 0 ,
+    "SIDE_KICK" : 1 , 
+    "FRONT_KICK" : 2 ,
+    "DOWNWARD_KICK" : 3 ,
+    "ROUND_KICK" : 4 ,
+    "BACK_KICK" : 5 ,
+    "BACK_ROUND_KICK" : 6 ,
+    "TURN_ROUND_KICK" : 7 ,
+}
+
+TAEKWONDO_LSTM_MAP_REVERSE = {
+    0 : "STANDBY" ,
+    1 : "SIDE_KICK", 
+    2 : "FRONT_KICK"  ,
+    3 : "DOWNWARD_KICK" ,
+    4 : "ROUND_KICK" ,
+    5 : "BACK_KICK" ,
+    6 : "BACK_ROUND_KICK" ,
+    7 : "TURN_ROUND_KICK" ,
+}
+TAEKWONDO_LABEL = [
+            "STANDBY",
+            "SIDE_KICK", 
+            "FRONT_KICK",
+            "DOWNWARD_KICK",
+            "ROUND_KICK",
+            "BACK_KICK",
+            "BACK_ROUND_KICK",
+            "TURN_ROUND_KICK",
+            "NONE"
+            ]
+
+MODEL_TRANSFORMER = 'transformer'
+MODEL_LSTM = 'lstm'
\ No newline at end of file
